@@ -1,3 +1,3 @@
-from app import create_app, start_app
+from .app import create_app, start_app
 from .components.base import Input, Output, State, MATCH, ALL, dcc, dbc, html, go, dash_table, pd
 from . import components
